==> qbittorrent_3.3.1.orig.tar.xz: qbittorrent-3.3.1/src/base/bittorrent/private/speedmonitor.cpp <==
/*
 * Bittorrent Client using Qt and libtorrent.
 * Copyright (C) 2015  Vladimir Golovnev <glassez@yandex.ru>
 * Copyright (C) 2011  Christophe Dumez <chris@qbittorrent.org>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * In addition, as a special exception, the copyright holders give permission to
 * link this program with the OpenSSL project's "OpenSSL" library (or with
 * modified versions of it that use the same license as the "OpenSSL" library),
 * and distribute the linked executables. You must obey the GNU General Public
 * License in all respects for all of the code used other than "OpenSSL".  If you
 * modify file(s), you may extend this exception to your version of the file(s),
 * but you are not obligated to do so. If you do not wish to do so, delete this
 * exception statement from your version.
 */

#include <QList>
#include "speedmonitor.h"

void SpeedMonitor::addSample(const SpeedSample &sample)
{
    m_speedSamples.push_back(sample);
    m_sum += sample;
    if (m_speedSamples.size() > MAX_SAMPLES) {
        m_sum -= m_speedSamples.front();
        m_speedSamples.pop_front();
    }
}

SpeedSampleAvg SpeedMonitor::average() const
{
    if (m_speedSamples.empty())
        return SpeedSampleAvg();

    qreal k = qreal(1.) / m_speedSamples.size();
    return SpeedSampleAvg(m_sum.download * k, m_sum.upload * k);
}

void SpeedMonitor::reset()
{
    m_sum = SpeedSample();
    m_speedSamples.clear();
}

==> qbittorrent_4.0.3.orig.tar.xz: qbittorrent-4.0.3/src/base/bittorrent/private/speedmonitor.cpp <==
/*
 * Bittorrent Client using Qt and libtorrent.
 * Copyright (C) 2015  Vladimir Golovnev <glassez@yandex.ru>
 * Copyright (C) 2011  Christophe Dumez <chris@qbittorrent.org>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * In addition, as a special exception, the copyright holders give permission to
 * link this program with the OpenSSL project's "OpenSSL" library (or with
 * modified versions of it that use the same license as the "OpenSSL" library),
 * and distribute the linked executables. You must obey the GNU General Public
 * License in all respects for all of the code used other than "OpenSSL".  If you
 * modify file(s), you may extend this exception to your version of the file(s),
 * but you are not obligated to do so. If you do not wish to do so, delete this
 * exception statement from your version.
 */

#include "speedmonitor.h"

SpeedMonitor::SpeedMonitor()
    : m_speedSamples(MAX_SAMPLES)
{
}

void SpeedMonitor::addSample(const SpeedSample &sample)
{
    if (m_speedSamples.size() >= MAX_SAMPLES) {
        m_sum -= m_speedSamples.front();
    }

    m_speedSamples.push_back(sample);
    m_sum += sample;
}

SpeedSampleAvg SpeedMonitor::average() const
{
    if (m_speedSamples.empty())
        return SpeedSampleAvg();

    qreal k = qreal(1.) / m_speedSamples.size();
    return SpeedSampleAvg(m_sum.download * k, m_sum.upload * k);
}

void SpeedMonitor::reset()
{
    m_sum = SpeedSample();
    m_speedSamples.clear();
}
